package jalview.io;

import java.io.File;
import java.io.FilenameFilter;
import java.io.IOException;

public class BackupFilenameFilter implements FilenameFilter
{

  public String base;

  public String template;

  public int digits;

  public BackupFilenameFilter(String base, String template, int digits)
  {
    this.base = base;
    this.template = template;
    this.digits = digits;
  }

  @Override
  public boolean accept(File dir, String filename)
  {
    try
    {
      File file = new File(
              dir.getCanonicalPath() + File.separatorChar + filename);
      if (file.isDirectory())
      {
        // backup files aren't dirs!
        return false;
      }
    } catch (IOException e)
    {
      System.out.println("IOException when checking file '" + filename
              + "' is a backupfile");
    }

    BackupFilenameParts bffp = new BackupFilenameParts(filename, base,
            template, digits);
    return bffp.isBackupFile();
  }

  public static String getBackupFilename(int index, String base,
          String template, int digits)
  {
    String numString = String.format("%0" + digits + "d", index);
    String backupSuffix = template.replaceAll(BackupFiles.NUM_PLACEHOLDER,
            numString);
    String backupfilename = base + backupSuffix;
    return backupfilename;
  }

}

